@@ -1,6 +1,5 @@
-function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }
-
-function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }
+import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
+import _regeneratorRuntime from "@babel/runtime/regenerator";
 
 /**
  * Copyright IBM Corp. 2016, 2018
@@ -10,7 +9,7 @@ function _asyncToGenerator(fn) { return function () { var self = this, args = ar
  */
 import React from 'react';
 import { ErrorFilled20 } from '@carbon/icons-react';
-import { NotificationButton, ToastNotification, InlineNotification, NotificationActionButton } from '../next/Notification';
+import { NotificationButton, ToastNotification, InlineNotification, ActionableNotification } from '../next/Notification';
 import { render, screen, waitFor } from '@testing-library/react';
 import userEvent from '@testing-library/user-event';
 import { settings } from 'carbon-components';
@@ -91,7 +90,7 @@ describe('ToastNotification', function () {
     expect(function () {
       render( /*#__PURE__*/React.createElement(ToastNotification, null, /*#__PURE__*/React.createElement("button", {
         type: "button"
-      }, "Sample text")));
+      }, "Sample button text")));
     }).toThrow();
     expect(spy).toHaveBeenCalled();
     spy.mockRestore();
@@ -113,9 +112,9 @@ describe('ToastNotification', function () {
     });
     expect(closeButton).not.toBeInTheDocument();
   });
-  it('calls `onClose` when notification is closed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
+  it('calls `onClose` when notification is closed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
     var onClose, closeButton;
-    return regeneratorRuntime.wrap(function _callee$(_context) {
+    return _regeneratorRuntime.wrap(function _callee$(_context) {
       while (1) {
         switch (_context.prev = _context.next) {
           case 0:
@@ -163,9 +162,9 @@ describe('ToastNotification', function () {
     userEvent.click(closeButton);
     expect(onCloseButtonClick).toHaveBeenCalledTimes(1);
   });
-  it('closes notification via escape button', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2() {
+  it('closes notification via escape button', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
     var onCloseButtonClick, onClose;
-    return regeneratorRuntime.wrap(function _callee2$(_context2) {
+    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
       while (1) {
         switch (_context2.prev = _context2.next) {
           case 0:
@@ -174,16 +173,22 @@ describe('ToastNotification', function () {
             render( /*#__PURE__*/React.createElement(ToastNotification, {
               onClose: onClose,
               onCloseButtonClick: onCloseButtonClick
-            }));
+            })); // without focus being on/in the notification, it should not close via escape
+
+            userEvent.keyboard('{Escape}');
+            expect(onCloseButtonClick).toHaveBeenCalledTimes(0);
+            expect(onClose).toHaveBeenCalledTimes(0); // after focus is placed, the notification should close via escape
+
+            userEvent.tab();
             userEvent.keyboard('{Escape}');
             expect(onCloseButtonClick).toHaveBeenCalledTimes(1);
             expect(onClose).toHaveBeenCalledTimes(1);
-            _context2.next = 8;
+            _context2.next = 12;
             return waitFor(function () {
               expect(screen.queryByRole('status')).not.toBeInTheDocument();
             });
 
-          case 8:
+          case 12:
           case "end":
             return _context2.stop();
         }
@@ -222,11 +227,15 @@ describe('InlineNotification', function () {
     render( /*#__PURE__*/React.createElement(InlineNotification, null, /*#__PURE__*/React.createElement("p", null, "Sample text")));
     expect(screen.queryByText(/Sample text/i)).toBeInTheDocument();
   });
-  it('allows interactive elements as children', function () {
-    render( /*#__PURE__*/React.createElement(InlineNotification, null, /*#__PURE__*/React.createElement("button", {
-      type: "button"
-    }, "Sample text")));
-    expect(screen.queryByText(/Sample text/i)).toBeInTheDocument();
+  it('does not allow interactive elements as children', function () {
+    var spy = jest.spyOn(console, 'error').mockImplementation(function () {});
+    expect(function () {
+      render( /*#__PURE__*/React.createElement(InlineNotification, null, /*#__PURE__*/React.createElement("button", {
+        type: "button"
+      }, "Sample button text")));
+    }).toThrow();
+    expect(spy).toHaveBeenCalled();
+    spy.mockRestore();
   });
   it('close button is rendered by default and includes aria-hidden=true', function () {
     render( /*#__PURE__*/React.createElement(InlineNotification, null));
@@ -245,9 +254,9 @@ describe('InlineNotification', function () {
     });
     expect(closeButton).not.toBeInTheDocument();
   });
-  it('calls `onClose` when notification is closed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3() {
+  it('calls `onClose` when notification is closed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
     var onClose, closeButton;
-    return regeneratorRuntime.wrap(function _callee3$(_context3) {
+    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
       while (1) {
         switch (_context3.prev = _context3.next) {
           case 0:
@@ -295,9 +304,9 @@ describe('InlineNotification', function () {
     userEvent.click(closeButton);
     expect(onCloseButtonClick).toHaveBeenCalledTimes(1);
   });
-  it('closes notification via escape button', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4() {
+  it('closes notification via escape button', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
     var onCloseButtonClick, onClose;
-    return regeneratorRuntime.wrap(function _callee4$(_context4) {
+    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
       while (1) {
         switch (_context4.prev = _context4.next) {
           case 0:
@@ -306,32 +315,79 @@ describe('InlineNotification', function () {
             render( /*#__PURE__*/React.createElement(InlineNotification, {
               onClose: onClose,
               onCloseButtonClick: onCloseButtonClick
-            }));
+            })); // without focus being on/in the notification, it should not close via escape
+
+            userEvent.keyboard('{Escape}');
+            expect(onCloseButtonClick).toHaveBeenCalledTimes(0);
+            expect(onClose).toHaveBeenCalledTimes(0); // after focus is placed, the notification should close via escape
+
+            userEvent.tab();
             userEvent.keyboard('{Escape}');
             expect(onCloseButtonClick).toHaveBeenCalledTimes(1);
             expect(onClose).toHaveBeenCalledTimes(1);
-            _context4.next = 8;
+            _context4.next = 12;
             return waitFor(function () {
               expect(screen.queryByRole('status')).not.toBeInTheDocument();
             });
 
-          case 8:
+          case 12:
           case "end":
             return _context4.stop();
         }
       }
     }, _callee4);
   })));
-  it('renders actions when provided, and overrides role to be alertdialog', function () {
-    var _render10 = render( /*#__PURE__*/React.createElement(InlineNotification, {
-      actions: /*#__PURE__*/React.createElement(NotificationActionButton, null, "Button text")
+});
+describe('ActionableNotification', function () {
+  it('uses role=alertdialog', function () {
+    var _render10 = render( /*#__PURE__*/React.createElement(ActionableNotification, {
+      actionButtonLabel: "My custom action"
     })),
         container = _render10.container;
 
-    var actionButton = screen.queryByRole('button', {
-      name: 'Button text'
-    });
-    expect(actionButton).toBeInTheDocument();
     expect(container.firstChild).toHaveAttribute('role', 'alertdialog');
   });
+  it('renders correct action label', function () {
+    render( /*#__PURE__*/React.createElement(ActionableNotification, {
+      actionButtonLabel: "My custom action"
+    }));
+    var actionButton = screen.queryByRole('button', {
+      name: 'My custom action'
+    });
+    expect(actionButton).toBeInTheDocument();
+  });
+  it('closes notification via escape button when focus is placed on the notification', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
+    var onCloseButtonClick, onClose;
+    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
+      while (1) {
+        switch (_context5.prev = _context5.next) {
+          case 0:
+            onCloseButtonClick = jest.fn();
+            onClose = jest.fn();
+            render( /*#__PURE__*/React.createElement(ActionableNotification, {
+              onClose: onClose,
+              onCloseButtonClick: onCloseButtonClick,
+              actionButtonLabel: "My custom action"
+            })); // without focus being on/in the notification, it should not close via escape
+
+            userEvent.keyboard('{Escape}');
+            expect(onCloseButtonClick).toHaveBeenCalledTimes(0);
+            expect(onClose).toHaveBeenCalledTimes(0); // after focus is placed, the notification should close via escape
+
+            userEvent.tab();
+            userEvent.keyboard('{Escape}');
+            expect(onCloseButtonClick).toHaveBeenCalledTimes(1);
+            expect(onClose).toHaveBeenCalledTimes(1);
+            _context5.next = 12;
+            return waitFor(function () {
+              expect(screen.queryByRole('alertdialog')).not.toBeInTheDocument();
+            });
+
+          case 12:
+          case "end":
+            return _context5.stop();
+        }
+      }
+    }, _callee5);
+  })));
 });
\ No newline at end of file
