@@ -1,5 +1,7 @@
 "use strict";
 
+var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
+
 var _react = _interopRequireDefault(require("react"));
 
 var _DatePicker = _interopRequireDefault(require("../DatePicker"));
@@ -10,8 +12,6 @@ var _enzyme = require("enzyme");
 
 var _DatePickerInput = _interopRequireDefault(require("../DatePickerInput/DatePickerInput"));
 
-function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
-
 /**
  * Copyright IBM Corp. 2016, 2018
  *
